@@ -3,6 +3,7 @@
 
 import argparse
 
+import rigidbodyfit.structure
 
 def get_command_line_arguments(version: str):
     """build, parse and return command line arguments
@@ -47,7 +48,7 @@ def get_command_line_arguments(version: str):
 
     parser.add_argument("--exclude",
                         type=str,
-                        default='H|W|CL|CLA|NA|SOD|K',
+                        default=rigidbodyfit.structure.DEFAULT_EXCLUDED_ATOMS,
                         help="discard atoms that contain these characters")
 
     parser.add_argument("--sampling-depth",
